@@ -39,9 +39,11 @@ except ImportError:
     from urllib2 import URLError
 
 import base64
-from catkin_pkg.package import InvalidPackage, parse_package_string
 import json
 import os
+
+from catkin_pkg.package import parse_package_string
+
 from rosdistro import logger
 
 GITHUB_USER = os.getenv('GITHUB_USER', None)
@@ -51,7 +53,7 @@ GITHUB_PASSWORD = os.getenv('GITHUB_PASSWORD', None)
 def github_manifest_provider(_dist_name, repo, pkg_name):
     assert repo.version
     server, path = repo.get_url_parts()
-    if server != 'github.com':
+    if not server.endswith('github.com'):
         logger.debug('Skip non-github url "%s"' % repo.url)
         raise RuntimeError('can not handle non github urls')
 
@@ -72,7 +74,7 @@ def github_manifest_provider(_dist_name, repo, pkg_name):
 
 def github_source_manifest_provider(repo):
     server, path = repo.get_url_parts()
-    if server != 'github.com':
+    if not server.endswith('github.com'):
         logger.debug('Skip non-github url "%s"' % repo.url)
         raise RuntimeError('can not handle non github urls')
 
@@ -109,13 +111,13 @@ def github_source_manifest_provider(repo):
                 return True
     package_xml_paths = list(filter(package_xml_in_parent, package_xml_paths))
 
-    cache = { '_ref': tree_json['sha'] }
+    cache = {'_ref': tree_json['sha']}
     for package_xml_path in package_xml_paths:
         url = 'https://raw.githubusercontent.com/%s/%s/%s' % \
             (path, cache['_ref'], package_xml_path + '/package.xml' if package_xml_path else 'package.xml')
         logger.debug('- load package.xml from %s' % url)
         package_xml = urlopen(url).read().decode('utf-8')
         name = parse_package_string(package_xml).name
-        cache[name] = [ package_xml_path, package_xml ]
+        cache[name] = [package_xml_path, package_xml]
 
     return cache
